@@ -61,6 +61,12 @@ class Segment:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Segment') -> bool:
+        return (self.start == other.start and self.end == other.end
+                or self.start == other.end and self.end == other.start
+                if isinstance(other, Segment)
+                else NotImplemented)
+
     @property
     def start(self) -> hints.Point:
         return self._start
@@ -122,6 +128,12 @@ class Box:
 
     __repr__ = generate_repr(__init__)
 
+    def __eq__(self, other: 'Box') -> bool:
+        return (self.min_x == other.min_x and self.max_x == other.max_x
+                and self.min_y == other.min_y and self.max_y == other.max_y
+                if isinstance(other, Box)
+                else NotImplemented)
+
     @property
     def max_x(self) -> hints.Coordinate:
         return self._max_x
