@@ -66,6 +66,10 @@ class Box(Protocol[Coordinate]):
                 max_y: Coordinate) -> 'Box':
         """Constructs box given its coordinates limits."""
 
+    @abstractmethod
+    def __eq__(self, other: 'Box') -> bool:
+        """Checks if the box is equal to the other."""
+
     @property
     @abstractmethod
     def max_x(self) -> Coordinate:
@@ -113,6 +117,10 @@ class Segment(Protocol[Coordinate]):
     def __new__(cls, start: Point, end: Point) -> 'Segment':
         """Constructs segment given its endpoints."""
 
+    @abstractmethod
+    def __eq__(self, other: 'Segment') -> bool:
+        """Checks if the segment is equal to the other."""
+
     @property
     @abstractmethod
     def start(self) -> Point:
